/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if !defined(_DATA_H)
#define _DATA_H

#include <watch_app.h>
#include <stdbool.h>
#include <stddef.h>
#include <time.h>

struct _xml_weather_city {
	char *name;
	char *country;
};

struct _xml_weather_temperature {
	double value;
};

struct _xml_weather_weather {
	char *icon;
};

typedef struct _xml_weather_city xml_weather_city_t;
typedef struct _xml_weather_temperature xml_weather_temperature_t;
typedef struct _xml_weather_weather xml_weather_weather_t;

struct _xml_weather {
	xml_weather_city_t city;
	xml_weather_temperature_t temperature;
	xml_weather_weather_t weather;
};

typedef struct _xml_weather xml_weather_t;

struct _date_time {
	int year;
	int month;
	int day;
	int day_of_week;
	int hour;
	int minute;
	int second;
};

typedef struct _date_time date_time_t;

/*
 * Initialize the data component
 */
void data_initialize(void);

/*
 * Finalize the data component
 */
void data_finalize(void);
void data_get_date_time_from_watch_time(const watch_time_h watch_time, date_time_t *dt);
bool data_get_weather(const char *xml_buffer, size_t buffer_size, xml_weather_t **weather);
void data_dispose_weather(xml_weather_t *weather);

#endif
